@@ -11,14 +11,14 @@ class LdapSearchResult(object):
         if 'dn' == key:
             return self.dn
         else:
-            return self.props[key]
+            return str(self.props[key])
 
     def has_property(self, prop):
         return prop in self.props
 
     def get(self, prop, default=None):
         if self.has_property(prop):
-            return self.props[prop]
+            return str(self.props[prop])
         else:
             return default
 
